@@ -14,7 +14,7 @@ function(x, ...)
         ord <- order(k)
         obj <- obj[ord]
         k <- k[ord]
-        dctmp <- t(sapply(obj, dclone:::extractdcdiag.default))
+        dctmp <- t(sapply(obj, dclone::extractdcdiag.default))
         Call <- match.call()
         mnam <- as.character(Call[-1])
         rval <- as.data.frame(dctmp)
